import { PropsWithChildren, ReactElement } from 'react';

export type Range = [start: number, end: number];
export type RenderFn = (props: PropsWithChildren) => ReactElement;
export type Decor = {
    /**
     * Range to apply decoration, including the start and end position.
     * Invalid part of the range will be ignored.
     */
    range: Range;
    /**
     * A function to render the text segment denoted by this the {@link range}.
     * If not specify, the text will be rendered within `<mark>`.
     */
    render?: RenderFn;
};
/**
 * Finds and creates {@link Decor} for all segments in the text that match the
 * query.
 *
 * Query could be either {@link string} or {@link RegExp}. If it's a non-global
 * `RegExp`, it will be cloned with the global flag to support finding all
 * matches in the text.
 *
 * If the option {@link render}is not specified, use the default one which will
 * wrap text segment within `<mark>`.
 */
export declare function match(text: string, query: string | RegExp, render?: RenderFn): Decor[];
export declare function split(length: number, decors: Decor[] | undefined): Seg[];
export type Seg = {
    range: Range;
    renders: RenderFn[];
};
export declare function defaultRenderFn(p: PropsWithChildren): import('react').DetailedReactHTMLElement<import('react').HTMLAttributes<HTMLElement>, HTMLElement>;
export declare function overlap(p: Seg, decor: Decor): Seg[];
